@@ -9,3 +9,7 @@ test_that("is not different compared to reference", {
   reference <- readRDS(test_path("ref-region_isos"))
   expect_identical(region_isos, reference)
 })
+
+test_that("isos are not duplicated per region, scenario", {
+  expect_false(any(duplicated(region_isos)))
+})
